Troubleshooting — influx_si 7.0 documentation

# Troubleshooting

The software is provided “AS IS” without warranty of any kind explicit or implicit.

If you have some issue with `influx_si` you can try the following steps for solving them:

> - partners and clients of MetaToul-RéseauxMétaboliques can benefit from advices of their dedicated stuff. If you are not a partner/client but would like to become one, for example to get help for your label experiment design and/or realization, you can contact platform MetaToul (cf. Consulting and more);

> - you can search for similar problem discussion in the forum https://groups.google.com/forum/#!forum/influx_si. If you don’t find your answer and wish to ask a new question you’ll have to subscribe to this group.

> - if you think that you face a bug, try the latest version of the software to see if this bug was already fixed. If it is still present, you can report it on https://github.com/sgsokol/influx/issues. Please note that we can’t guarantee that any particular bug can be fixed in any particular release or can be fixed at all. It is possible, that we ask you to send us (in a private email not in influx_si@googlegroups.com) your input files to reproduce the error on our side. It will be used only for purposes of issue resolving. The received files will not be transmitted to any third party.